package com.ynet.life.sujrb.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.web.multipart.implement.GENEMultipartFile;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.net.ftp.FtpService;
import java.io.File;
import java.io.IOException;
import org.apache.commons.net.ftp.FTPClient;

/* loaded from: com_ynet_life_sujrb_action.jar:com/ynet/life/sujrb/action/FtpUploadAction.class */
public class FtpUploadAction extends LifeAction {
    private static final char DIR_SEPERATOR = '/';
    private String fileUploadField;
    private String ftpFileField;
    private boolean binaryFile;

    public String execute(Context context) throws GENEException {
        String clusterMode = LifeStandard.getSystemParam("PB_CLUSTER_MODE");
        try {
            String filePathName = ((GENEMultipartFile) context.getDataValue(this.fileUploadField)).getTempFileName();
            String fileName = new File(filePathName).getName();
            String date = LifeStandard.getServerTime("yyyyMMdd");
            String time = LifeStandard.getServerTime("HHmmss");
            String customerId = (String) getSessionCtx(context).getDataValue("customerId");
            if ("0".equals(clusterMode)) {
                String filePath = LifeStandard.getSelfDefineSettingsValue("tempDownloadDir");
                String workingDirectory = String.valueOf(date) + '/' + time + '/' + customerId;
                String filePath2 = String.valueOf(filePath) + '/' + workingDirectory;
                if (!new File(filePath2).isDirectory()) {
                    new File(filePath2).mkdirs();
                }
                new File(filePathName).renameTo(new File(String.valueOf(filePath2) + '/' + fileName));
                context.setDataValue(this.ftpFileField, String.valueOf(workingDirectory) + '/' + fileName);
                return "0";
            }
            FtpService ftpService = (FtpService) context.getService("FtpService");
            FTPClient ftpClient = null;
            try {
                ftpClient = ftpService.initConnection();
                ftpService.setTransferMode(ftpClient, this.binaryFile);
                String workingDirectory2 = String.valueOf(date) + '/' + time + '/' + customerId;
                ftpService.makeMultiDirectory(ftpClient, workingDirectory2);
                ftpService.changeWorkingDirectory(ftpClient, workingDirectory2);
                ftpService.uploadFile(ftpClient, filePathName, fileName);
                String ftpFilePath = String.valueOf(workingDirectory2) + '/' + fileName;
                context.setDataValue(this.ftpFileField, ftpFilePath);
                if (ftpClient != null) {
                    try {
                        ftpClient.logout();
                        return "0";
                    } catch (IOException ex) {
                        Trace.logError("LifeAction", "FTP上传文件异常", ex);
                        throw new GENEException(ex);
                    }
                }
                return "0";
            } catch (Throwable th) {
                if (ftpClient != null) {
                    try {
                        ftpClient.logout();
                    } catch (IOException ex2) {
                        Trace.logError("LifeAction", "FTP上传文件异常", ex2);
                        throw new GENEException(ex2);
                    }
                }
                throw th;
            }
        } catch (GENEException e) {
            Trace.logError("LifeAction", "FTP上传文件异常", e);
            throw e;
        }
    }

    public void setFileUploadField(String fileUploadField) {
        this.fileUploadField = fileUploadField;
    }

    public void setFtpFileField(String ftpFileField) {
        this.ftpFileField = ftpFileField;
    }

    public void setBinaryFile(boolean binaryFile) {
        this.binaryFile = binaryFile;
    }
}
